pub struct Connection { /* private fields */ }Implementations
Sourceimpl Connection
impl Connection
Sourcepub fn new(endpoint: String) -> Connection
pub fn new(endpoint: String) -> Connection
Create Connection
Sourceimpl Connection
impl Connection
Sourcepub fn new_with_commitment(endpoint: String, commitment: String) -> Connection
pub fn new_with_commitment(endpoint: String, commitment: String) -> Connection
Create Connection
Sourceimpl Connection
impl Connection
Sourcepub async fn get_latest_block_hash_impl(&self) -> Result<JsValue>
pub async fn get_latest_block_hash_impl(&self) -> Result<JsValue>
Fetch the latest blockhash from the cluster
Sourceimpl Connection
impl Connection
Sourcepub async fn get_latest_block_hash_with_commitment(
&self,
commitment: String,
) -> Result<JsValue>
pub async fn get_latest_block_hash_with_commitment( &self, commitment: String, ) -> Result<JsValue>
Fetch the latest blockhash from the cluster
Sourceimpl Connection
impl Connection
Sourcepub async fn send_raw_transaction(&self, tx: JsValue) -> Result<JsValue>
pub async fn send_raw_transaction(&self, tx: JsValue) -> Result<JsValue>
Send a transaction that has already been signed and serialized into the wire format
Sourceimpl Connection
impl Connection
Sourceimpl Connection
impl Connection
Sourcepub async fn get_account_info_impl(
&self,
public_key: JsValue,
) -> Result<JsValue>
pub async fn get_account_info_impl( &self, public_key: JsValue, ) -> Result<JsValue>
Fetch all the account info for the specified public key
Sourceimpl Connection
impl Connection
Sourceimpl Connection
impl Connection
Sourcepub async fn get_program_accounts_with_config_impl(
&self,
public_key: JsValue,
config: RpcProgramAccountsConfig,
) -> Result<JsValue>
pub async fn get_program_accounts_with_config_impl( &self, public_key: JsValue, config: RpcProgramAccountsConfig, ) -> Result<JsValue>
Fetch all the account info for the specified public key
Sourceimpl Connection
impl Connection
pub async fn get_latest_block_hash(&self) -> Result<LatestBlockhashInfo>
pub async fn get_account_info(&self, pubkey: &Pubkey) -> Result<Account>
pub async fn get_account_info_with_options( &self, pubkey: &Pubkey, options: JsValue, ) -> Result<JsValue>
pub async fn send_raw_transaction_with_options( &self, tx: JsValue, options: SendRawTxOptions, ) -> Result<JsValue>
pub async fn get_program_accounts_with_config( &self, pubkey: &Pubkey, config: RpcProgramAccountsConfig, ) -> Result<Vec<(Pubkey, Account)>>
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn as_f64(&self) -> Option<f64>
pub fn as_f64(&self) -> Option<f64>
Returns the f64 value of this JS value if it’s an instance of a
number.
If this JS value is not an instance of a number then this returns
None.
Sourcepub fn as_string(&self) -> Option<String>
pub fn as_string(&self) -> Option<String>
If this JS value is a string value, this function copies the JS string
value into Wasm linear memory, encoded as UTF-8, and returns it as a
Rust String.
To avoid the copying and re-encoding, consider the
JsString::try_from() function from js-sys
instead.
If this JS value is not an instance of a string or if it’s not valid
utf-8 then this returns None.
UTF-16 vs UTF-8
JavaScript strings in general are encoded as UTF-16, but Rust strings
are encoded as UTF-8. This can cause the Rust string to look a bit
different than the JS string sometimes. For more details see the
documentation about the str type which contains a few
caveats about the encodings.
Sourcepub fn as_bool(&self) -> Option<bool>
pub fn as_bool(&self) -> Option<bool>
Returns the bool value of this JS value if it’s an instance of a
boolean.
If this JS value is not an instance of a boolean then this returns
None.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Tests whether this JS value is undefined
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Tests whether the type of this JS value is function.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Applies the binary in JS operator on the two JsValues.
Sourcepub fn loose_eq(&self, other: &JsValue) -> bool
pub fn loose_eq(&self, other: &JsValue) -> bool
Compare two JsValues for equality, using the == operator in JS.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Applies the binary >>> JS operator on the two JsValues.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.
Sourcepub fn pow(&self, rhs: &JsValue) -> JsValue
pub fn pow(&self, rhs: &JsValue) -> JsValue
Applies the binary ** JS operator on the two JsValues.
Sourcepub fn lt(&self, other: &JsValue) -> bool
pub fn lt(&self, other: &JsValue) -> bool
Applies the binary < JS operator on the two JsValues.
Sourcepub fn le(&self, other: &JsValue) -> bool
pub fn le(&self, other: &JsValue) -> bool
Applies the binary <= JS operator on the two JsValues.
Sourcepub fn ge(&self, other: &JsValue) -> bool
pub fn ge(&self, other: &JsValue) -> bool
Applies the binary >= JS operator on the two JsValues.
Sourcepub fn gt(&self, other: &JsValue) -> bool
pub fn gt(&self, other: &JsValue) -> bool
Applies the binary > JS operator on the two JsValues.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Applies the unary + JS operator on a JsValue. Can throw.